@@ -1,5 +1,5 @@
-use pyo3::prelude::*;
 use pyo3::types::{PyDict, PySet};
+use pyo3::{prelude::*, IntoPyObjectExt};
 
 use crate::errors::ValResult;
 use crate::input::{validate_iter_to_set, BorrowInput, ConsumeIterator, Input, ValidatedSet};
@@ -15,6 +15,7 @@ pub struct SetValidator {
     min_length: Option<usize>,
     max_length: Option<usize>,
     name: String,
+    fail_fast: bool,
 }
 
 macro_rules! set_build {
@@ -42,6 +43,7 @@ macro_rules! set_build {
                 min_length: schema.get_as(pyo3::intern!(py, "min_length"))?,
                 max_length,
                 name,
+                fail_fast: schema.get_as(pyo3::intern!(py, "fail_fast"))?.unwrap_or(false),
             }
             .into())
         }
@@ -64,7 +66,7 @@ impl Validator for SetValidator {
         state: &mut ValidationState<'_, 'py>,
     ) -> ValResult<PyObject> {
         let collection = input.validate_set(state.strict_or(self.strict))?.unpack(state);
-        let set = PySet::empty_bound(py)?;
+        let set = PySet::empty(py)?;
         collection.iterate(ValidateToSet {
             py,
             input,
@@ -72,9 +74,10 @@ impl Validator for SetValidator {
             max_length: self.max_length,
             item_validator: &self.item_validator,
             state,
+            fail_fast: self.fail_fast,
         })??;
         min_length_check!(input, "Set", self.min_length, set);
-        Ok(set.into_py(py))
+        Ok(set.into_py_any(py)?)
     }
 
     fn get_name(&self) -> &str {
@@ -89,6 +92,7 @@ struct ValidateToSet<'a, 's, 'py, I: Input<'py> + ?Sized> {
     max_length: Option<usize>,
     item_validator: &'a CombinedValidator,
     state: &'a mut ValidationState<'s, 'py>,
+    fail_fast: bool,
 }
 
 impl<'py, T, I> ConsumeIterator<PyResult<T>> for ValidateToSet<'_, '_, 'py, I>
@@ -107,6 +111,7 @@ where
             self.max_length,
             self.item_validator,
             self.state,
+            self.fail_fast,
         )
     }
 }
