@@ -1,6 +1,7 @@
 use pyo3::intern;
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyString};
+use pyo3::IntoPyObjectExt;
 use regex::Regex;
 
 use crate::build_tools::{is_strict, py_schema_error_type, schema_or_config, schema_or_config_same};
@@ -49,7 +50,12 @@ impl Validator for StrValidator {
     ) -> ValResult<PyObject> {
         input
             .validate_str(state.strict_or(self.strict), self.coerce_numbers_to_str)
-            .map(|val_match| val_match.unpack(state).as_py_string(py, state.cache_str()).into_py(py))
+            .and_then(|val_match| {
+                Ok(val_match
+                    .unpack(state)
+                    .as_py_string(py, state.cache_str())
+                    .into_py_any(py)?)
+            })
     }
 
     fn get_name(&self) -> &str {
@@ -138,10 +144,10 @@ impl Validator for StrConstrainedValidator {
             // we haven't modified the string, return the original as it might be a PyString
             either_str.as_py_string(py, state.cache_str())
         };
-        Ok(py_string.into_py(py))
+        Ok(py_string.into_py_any(py)?)
     }
 
-    fn get_name(&self) -> &str {
+    fn get_name(&self) -> &'static str {
         "constrained-str"
     }
 }
@@ -164,7 +170,7 @@ impl StrConstrainedValidator {
                     .map(|s| s.to_str())
                     .transpose()?
                     .unwrap_or(RegexEngine::RUST_REGEX);
-                Pattern::compile(py, s, regex_engine)
+                Pattern::compile(s, regex_engine)
             })
             .transpose()?;
         let min_length: Option<usize> =
@@ -200,7 +206,7 @@ impl StrConstrainedValidator {
     }
 
     // whether any of the constraints/customisations are actually enabled
-    // except strict which can be set on StrValidator
+    // except strict and coerce_numbers_to_str which can be set on StrValidator
     fn has_constraints_set(&self) -> bool {
         self.pattern.is_some()
             || self.max_length.is_some()
@@ -229,25 +235,54 @@ impl RegexEngine {
 }
 
 impl Pattern {
-    fn compile(py: Python<'_>, pattern: String, engine: &str) -> PyResult<Self> {
-        let engine = match engine {
-            RegexEngine::RUST_REGEX => {
-                RegexEngine::RustRegex(Regex::new(&pattern).map_err(|e| py_schema_error_type!("{}", e))?)
-            }
-            RegexEngine::PYTHON_RE => {
-                let re_compile = py.import_bound(intern!(py, "re"))?.getattr(intern!(py, "compile"))?;
-                RegexEngine::PythonRe(re_compile.call1((&pattern,))?.into())
-            }
-            _ => return Err(py_schema_error_type!("Invalid regex engine: {}", engine)),
-        };
-        Ok(Self { pattern, engine })
+    fn extract_pattern_str(pattern: &Bound<'_, PyAny>) -> PyResult<String> {
+        if pattern.is_instance_of::<PyString>() {
+            Ok(pattern.to_string())
+        } else {
+            pattern
+                .getattr("pattern")
+                .and_then(|attr| attr.extract::<String>())
+                .map_err(|_| py_schema_error_type!("Invalid pattern, must be str or re.Pattern: {}", pattern))
+        }
+    }
+
+    fn compile(pattern: Bound<'_, PyAny>, engine: &str) -> PyResult<Self> {
+        let pattern_str = Self::extract_pattern_str(&pattern)?;
+
+        let py = pattern.py();
+
+        let re_module = py.import(intern!(py, "re"))?;
+        let re_compile = re_module.getattr(intern!(py, "compile"))?;
+        let re_pattern = re_module.getattr(intern!(py, "Pattern"))?;
+
+        if pattern.is_instance(&re_pattern)? {
+            // if the pattern is already a compiled regex object, we default to using the python re engine
+            // so that any flags, etc. are preserved
+            Ok(Self {
+                pattern: pattern_str,
+                engine: RegexEngine::PythonRe(pattern.unbind()),
+            })
+        } else {
+            let engine = match engine {
+                RegexEngine::RUST_REGEX => {
+                    RegexEngine::RustRegex(Regex::new(&pattern_str).map_err(|e| py_schema_error_type!("{}", e))?)
+                }
+                RegexEngine::PYTHON_RE => RegexEngine::PythonRe(re_compile.call1((pattern,))?.into()),
+                _ => return Err(py_schema_error_type!("Invalid regex engine: {}", engine)),
+            };
+
+            Ok(Self {
+                pattern: pattern_str,
+                engine,
+            })
+        }
     }
 
     fn is_match(&self, py: Python<'_>, target: &str) -> PyResult<bool> {
         match &self.engine {
             RegexEngine::RustRegex(regex) => Ok(regex.is_match(target)),
             RegexEngine::PythonRe(py_regex) => {
-                Ok(!py_regex.call_method1(py, intern!(py, "match"), (target,))?.is_none(py))
+                Ok(!py_regex.call_method1(py, intern!(py, "search"), (target,))?.is_none(py))
             }
         }
     }
