@@ -83,16 +83,20 @@ def schema(*, strict: bool = False) -> dict:
                         'max_length': 42,
                     },
                 },
-                'field_tuple_var_len_any': {'type': 'model-field', 'schema': {'type': 'tuple-variable'}},
+                'field_tuple_var_len_any': {
+                    'type': 'model-field',
+                    'schema': {'type': 'tuple', 'items_schema': [{'type': 'any'}], 'variadic_item_index': 0},
+                },
                 'field_tuple_var_len_float': {
                     'type': 'model-field',
-                    'schema': {'type': 'tuple-variable', 'items_schema': {'type': 'float'}},
+                    'schema': {'type': 'tuple', 'items_schema': [{'type': 'float'}], 'variadic_item_index': 0},
                 },
                 'field_tuple_var_len_float_con': {
                     'type': 'model-field',
                     'schema': {
-                        'type': 'tuple-variable',
-                        'items_schema': {'type': 'float'},
+                        'type': 'tuple',
+                        'items_schema': [{'type': 'float'}],
+                        'variadic_item_index': 0,
                         'min_length': 3,
                         'max_length': 42,
                     },
@@ -100,7 +104,7 @@ def schema(*, strict: bool = False) -> dict:
                 'field_tuple_fix_len': {
                     'type': 'model-field',
                     'schema': {
-                        'type': 'tuple-positional',
+                        'type': 'tuple',
                         'items_schema': [{'type': 'str'}, {'type': 'int'}, {'type': 'float'}, {'type': 'bool'}],
                     },
                 },
@@ -249,10 +253,10 @@ def input_data_lax():
         'field_frozenset_bytes': frozenset([f'{i}'.encode() for i in range(100)]),
         'field_frozenset_bytes_con': frozenset([f'{i}'.encode() for i in range(42)]),
         'field_tuple_var_len_any': ('a', b'b', True, 1.0, None),
-        'field_tuple_var_len_float': tuple((i + 0.5 for i in range(100))),
-        'field_tuple_var_len_float_con': tuple((i + 0.5 for i in range(42))),
+        'field_tuple_var_len_float': tuple(i + 0.5 for i in range(100)),
+        'field_tuple_var_len_float_con': tuple(i + 0.5 for i in range(42)),
         'field_tuple_fix_len': ('a', 1, 1.0, True),
-        'field_dict_any': {'a': 'b', 1: True, 1.0: 1.0},
+        'field_dict_any': {'a': 'b', 1: True, 1.0: 1.0},  # noqa: F601
         'field_dict_str_float': {f'{i}': i + 0.5 for i in range(100)},
         'field_literal_1_int': 1,
         'field_literal_1_str': 'foobar',
@@ -336,3 +340,22 @@ def input_data_wrong():
         'field_functions_model': {'field_before': 1, 'field_after': 1, 'field_wrap': 1, 'field_plain': 1},
         'field_recursive': {'name': 'foo', 'sub_branch': {'name': 'bar', 'sub_branch': {}}},
     }
+
+
+def wrap_schema_in_root_model(schema: dict) -> dict:
+    class MyRootModel:
+        # __slots__ is not required, but it avoids __pydantic_fields_set__ falling into __dict__
+        __slots__ = '__dict__', '__pydantic_fields_set__', '__pydantic_extra__', '__pydantic_private__'
+
+    return {
+        'type': 'model',
+        'cls': MyRootModel,
+        'config': {},
+        'schema': {
+            'type': 'model-fields',
+            'fields': {
+                'root': {'type': 'model-field', 'schema': schema},
+            },
+        },
+        'root_model': True,
+    }
