@@ -1,10 +1,15 @@
 import json
-import re
 from functools import partial
 
 import pytest
 
-from pydantic_core import SchemaError, SchemaSerializer, core_schema, validate_core_schema
+from pydantic_core import (
+    PydanticSerializationError,
+    SchemaError,
+    SchemaSerializer,
+    core_schema,
+    validate_core_schema,
+)
 
 
 def test_list_any():
@@ -18,27 +23,35 @@ def test_list_any():
 
 def test_list_fallback():
     v = SchemaSerializer(core_schema.list_schema(core_schema.any_schema()))
-    msg = 'Expected `list[any]` but got `str` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r"Expected `list\[any\]` - serialized value may not be as expected \[input_value='apple', input_type=str\]",
+    ):
         assert v.to_python('apple') == 'apple'
 
     with pytest.warns(UserWarning) as warning_info:
         assert v.to_json('apple') == b'"apple"'
-    assert [w.message.args[0] for w in warning_info.list] == [
-        'Pydantic serializer warnings:\n  Expected `list[any]` but got `str` - serialized value may not be as expected'
-    ]
+    "Expected `list[any]` - serialized value may not be as expected [input_value='apple', input_type=str]" in warning_info.list[
+        0
+    ].message.args[0]
 
-    msg = 'Expected `list[any]` but got `bytes` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r"Expected `list\[any\]` - serialized value may not be as expected \[input_value=b'apple', input_type=bytes\]",
+    ):
         assert v.to_json(b'apple') == b'"apple"'
 
-    msg = 'Expected `list[any]` but got `tuple` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r'Expected `list\[any\]` - serialized value may not be as expected \[input_value=\(1, 2, 3\), input_type=tuple\]',
+    ):
         assert v.to_python((1, 2, 3)) == (1, 2, 3)
 
     # # even though we're in the fallback state, non JSON types should still be converted to JSON here
-    msg = 'Expected `list[any]` but got `tuple` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r'Expected `list\[any\]` - serialized value may not be as expected \[input_value=\(1, 2, 3\), input_type=tuple\]',
+    ):
         assert v.to_python((1, 2, 3), mode='json') == [1, 2, 3]
 
 
@@ -46,13 +59,21 @@ def test_list_str_fallback():
     v = SchemaSerializer(core_schema.list_schema(core_schema.str_schema()))
     with pytest.warns(UserWarning) as warning_info:
         assert v.to_json([1, 2, 3]) == b'[1,2,3]'
-    assert [w.message.args[0] for w in warning_info.list] == [
-        'Pydantic serializer warnings:\n'
-        '  Expected `str` but got `int` - serialized value may not be as expected\n'
-        '  Expected `str` but got `int` - serialized value may not be as expected\n'
-        '  Expected `str` but got `int` - serialized value may not be as expected'
+
+    expected_warnings = [
+        'Expected `str` - serialized value may not be as expected [input_value=1, input_type=int]',
+        'Expected `str` - serialized value may not be as expected [input_value=2, input_type=int]',
+        'Expected `str` - serialized value may not be as expected [input_value=3, input_type=int]',
     ]
 
+    all_warnings = ''.join([w.message.args[0] for w in warning_info.list])
+    assert all([x in all_warnings for x in expected_warnings])
+
+    with pytest.raises(PydanticSerializationError) as warning_ex:
+        v.to_json([1, 2, 3], warnings='error')
+
+    assert all([x in str(warning_ex.value) for x in expected_warnings])
+
 
 def test_tuple_any():
     v = SchemaSerializer(core_schema.tuple_variable_schema(core_schema.any_schema()))
@@ -233,26 +254,33 @@ def test_include_error_call_time(schema_func, seq_f, include, exclude):
 
 def test_tuple_fallback():
     v = SchemaSerializer(core_schema.tuple_variable_schema(core_schema.any_schema()))
-    msg = 'Expected `tuple[any, ...]` but got `str` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r"Expected `tuple\[any, ...\]` - serialized value may not be as expected \[input_value='apple', input_type=str\]",
+    ):
         assert v.to_python('apple') == 'apple'
 
     with pytest.warns(UserWarning) as warning_info:
         assert v.to_json([1, 2, 3]) == b'[1,2,3]'
-    assert [w.message.args[0] for w in warning_info.list] == [
-        'Pydantic serializer warnings:\n  Expected `tuple[any, ...]` but got `list` - '
-        'serialized value may not be as expected'
-    ]
 
-    msg = 'Expected `tuple[any, ...]` but got `bytes` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    assert (
+        'Expected `tuple[any, ...]` - serialized value may not be as expected [input_value=[1, 2, 3], input_type=list]'
+        in warning_info.list[0].message.args[0]
+    )
+
+    with pytest.warns(
+        UserWarning,
+        match=r"Expected `tuple\[any, ...\]` - serialized value may not be as expected \[input_value=b'apple', input_type=bytes\]",
+    ):
         assert v.to_json(b'apple') == b'"apple"'
 
     assert v.to_python((1, 2, 3)) == (1, 2, 3)
 
     # even though we're in the fallback state, non JSON types should still be converted to JSON here
-    msg = 'Expected `tuple[any, ...]` but got `list` - serialized value may not be as expected'
-    with pytest.warns(UserWarning, match=re.escape(msg)):
+    with pytest.warns(
+        UserWarning,
+        match=r'Expected `tuple\[any, ...\]` - serialized value may not be as expected \[input_value=\[1, 2, 3\], input_type=list\]',
+    ):
         assert v.to_python([1, 2, 3], mode='json') == [1, 2, 3]
 
 
@@ -382,13 +410,13 @@ def test_function_positional_tuple():
 
 def test_list_dict_key():
     s = SchemaSerializer(core_schema.dict_schema(core_schema.list_schema(), core_schema.int_schema()))
-    with pytest.warns(UserWarning, match=r'Expected `list\[any\]` but got `str`'):
+    with pytest.warns(UserWarning, match=r'Expected `list\[any\]`.+ input_type=str'):
         assert s.to_python({'xx': 1}) == {'xx': 1}
 
 
 def test_tuple_var_dict_key():
     s = SchemaSerializer(core_schema.dict_schema(core_schema.tuple_variable_schema(), core_schema.int_schema()))
-    with pytest.warns(UserWarning, match=r'Expected `tuple\[any, ...\]` but got `str`'):
+    with pytest.warns(UserWarning, match=r'Expected `tuple\[any, ...\]`.+input_type=str'):
         assert s.to_python({'xx': 1}) == {'xx': 1}
 
     assert s.to_python({(1, 2): 1}) == {(1, 2): 1}
@@ -411,3 +439,29 @@ def test_tuple_pos_dict_key():
     assert s.to_python({(1, 'a', 2): 1}, mode='json') == {'1,a,2': 1}
     assert s.to_json({(1, 'a'): 1}) == b'{"1,a":1}'
     assert s.to_json({(1, 'a', 2): 1}) == b'{"1,a,2":1}'
+
+
+def test_tuple_wrong_size_union():
+    # See https://github.com/pydantic/pydantic/issues/8677
+
+    f = core_schema.float_schema()
+    s = SchemaSerializer(
+        core_schema.union_schema([core_schema.tuple_schema([f, f]), core_schema.tuple_schema([f, f, f])])
+    )
+    assert s.to_python((1.0, 2.0)) == (1.0, 2.0)
+    assert s.to_python((1.0, 2.0, 3.0)) == (1.0, 2.0, 3.0)
+
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        s.to_python((1.0, 2.0, 3.0, 4.0))
+
+    assert s.to_python((1.0, 2.0), mode='json') == [1.0, 2.0]
+    assert s.to_python((1.0, 2.0, 3.0), mode='json') == [1.0, 2.0, 3.0]
+
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        s.to_python((1.0, 2.0, 3.0, 4.0), mode='json')
+
+    assert s.to_json((1.0, 2.0)) == b'[1.0,2.0]'
+    assert s.to_json((1.0, 2.0, 3.0)) == b'[1.0,2.0,3.0]'
+
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        s.to_json((1.0, 2.0, 3.0, 4.0))
