@@ -16,21 +16,19 @@ from pydantic_core import (
     core_schema,
 )
 
-from ..conftest import PyAndJson, assert_gc
+from ..conftest import PyAndJson, assert_gc, is_free_threaded
 
 
 def test_typed_dict_default():
     v = SchemaValidator(
-        {
-            'type': 'typed-dict',
-            'fields': {
-                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
-                'y': {
-                    'type': 'typed-dict-field',
-                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': '[default]'},
-                },
-            },
-        }
+        core_schema.typed_dict_schema(
+            fields={
+                'x': core_schema.typed_dict_field(schema=core_schema.str_schema()),
+                'y': core_schema.typed_dict_field(
+                    schema=core_schema.with_default_schema(schema=core_schema.str_schema(), default='[default]')
+                ),
+            }
+        )
     )
     assert v.validate_python({'x': 'x', 'y': 'y'}) == {'x': 'x', 'y': 'y'}
     assert v.validate_python({'x': 'x'}) == {'x': 'x', 'y': '[default]'}
@@ -38,17 +36,15 @@ def test_typed_dict_default():
 
 def test_typed_dict_omit():
     v = SchemaValidator(
-        {
-            'type': 'typed-dict',
-            'fields': {
-                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
-                'y': {
-                    'type': 'typed-dict-field',
-                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'omit'},
-                    'required': False,
-                },
-            },
-        }
+        core_schema.typed_dict_schema(
+            fields={
+                'x': core_schema.typed_dict_field(schema=core_schema.str_schema()),
+                'y': core_schema.typed_dict_field(
+                    schema=core_schema.with_default_schema(schema=core_schema.str_schema(), on_error='omit'),
+                    required=False,
+                ),
+            }
+        )
     )
     assert v.validate_python({'x': 'x', 'y': 'y'}) == {'x': 'x', 'y': 'y'}
     assert v.validate_python({'x': 'x'}) == {'x': 'x'}
@@ -57,16 +53,17 @@ def test_typed_dict_omit():
 
 def test_arguments():
     v = SchemaValidator(
-        {
-            'type': 'arguments',
-            'arguments_schema': [
+        core_schema.arguments_schema(
+            arguments=[
                 {
                     'name': 'a',
                     'mode': 'positional_or_keyword',
-                    'schema': {'type': 'default', 'schema': {'type': 'int'}, 'default_factory': lambda: 1},
+                    'schema': core_schema.with_default_schema(
+                        schema=core_schema.int_schema(), default_factory=lambda: 1
+                    ),
                 }
-            ],
-        }
+            ]
+        )
     )
     assert v.validate_python({'a': 2}) == ((), {'a': 2})
     assert v.validate_python(ArgsKwargs((2,))) == ((2,), {})
@@ -77,16 +74,17 @@ def test_arguments():
 def test_arguments_omit():
     with pytest.raises(SchemaError, match="Parameter 'a': omit_on_error cannot be used with arguments"):
         SchemaValidator(
-            {
-                'type': 'arguments',
-                'arguments_schema': [
+            schema=core_schema.arguments_schema(
+                arguments=[
                     {
                         'name': 'a',
                         'mode': 'positional_or_keyword',
-                        'schema': {'type': 'default', 'schema': {'type': 'int'}, 'default': 1, 'on_error': 'omit'},
+                        'schema': core_schema.with_default_schema(
+                            schema=core_schema.int_schema(), default=1, on_error='omit'
+                        ),
                     }
-                ],
-            }
+                ]
+            )
         )
 
 
@@ -113,7 +111,9 @@ def test_list_json(py_and_json: PyAndJson, input_value, expected):
 )
 def test_list(input_value, expected):
     v = SchemaValidator(
-        {'type': 'list', 'items_schema': {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'}}
+        core_schema.list_schema(
+            items_schema=core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='omit')
+        )
     )
     assert v.validate_python(input_value) == expected
 
@@ -130,7 +130,9 @@ def test_list(input_value, expected):
 )
 def test_set(input_value, expected):
     v = SchemaValidator(
-        {'type': 'set', 'items_schema': {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'}}
+        core_schema.set_schema(
+            items_schema=core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='omit')
+        )
     )
     assert v.validate_python(input_value) == expected
 
@@ -150,11 +152,10 @@ def test_dict_values(py_and_json: PyAndJson):
 
 def test_dict_keys():
     v = SchemaValidator(
-        {
-            'type': 'dict',
-            'keys_schema': {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'},
-            'values_schema': {'type': 'str'},
-        }
+        core_schema.dict_schema(
+            keys_schema=core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='omit'),
+            values_schema=core_schema.str_schema(),
+        )
     )
     assert v.validate_python({1: 'a', '2': 'b'}) == {1: 'a', 2: 'b'}
     assert v.validate_python({1: 'a', 'wrong': 'b'}) == {1: 'a'}
@@ -176,10 +177,12 @@ def test_tuple_variable(py_and_json: PyAndJson):
 
 def test_tuple_positional():
     v = SchemaValidator(
-        {
-            'type': 'tuple',
-            'items_schema': [{'type': 'int'}, {'type': 'default', 'schema': {'type': 'int'}, 'default': 42}],
-        }
+        core_schema.tuple_schema(
+            items_schema=[
+                core_schema.int_schema(),
+                core_schema.with_default_schema(schema=core_schema.int_schema(), default=42),
+            ]
+        )
     )
     assert v.validate_python((1, '2')) == (1, 2)
     assert v.validate_python([1, '2']) == (1, 2)
@@ -189,15 +192,14 @@ def test_tuple_positional():
 
 def test_tuple_positional_omit():
     v = SchemaValidator(
-        {
-            'type': 'tuple',
-            'items_schema': [
-                {'type': 'int'},
-                {'type': 'int'},
-                {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'},
+        core_schema.tuple_schema(
+            items_schema=[
+                core_schema.int_schema(),
+                core_schema.int_schema(),
+                core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='omit'),
             ],
-            'variadic_item_index': 2,
-        }
+            variadic_item_index=2,
+        )
     )
     assert v.validate_python((1, '2')) == (1, 2)
     assert v.validate_python((1, '2', 3, '4')) == (1, 2, 3, 4)
@@ -207,7 +209,7 @@ def test_tuple_positional_omit():
 
 
 def test_on_error_default():
-    v = SchemaValidator({'type': 'default', 'schema': {'type': 'int'}, 'default': 2, 'on_error': 'default'})
+    v = SchemaValidator(core_schema.with_default_schema(schema=core_schema.int_schema(), default=2, on_error='default'))
     assert v.validate_python(42) == 42
     assert v.validate_python('42') == 42
     assert v.validate_python('wrong') == 2
@@ -218,7 +220,7 @@ def test_factory_runtime_error():
         raise RuntimeError('this is broken')
 
     v = SchemaValidator(
-        {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'default', 'default_factory': broken}
+        core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='default', default_factory=broken)
     )
     assert v.validate_python(42) == 42
     assert v.validate_python('42') == 42
@@ -231,13 +233,12 @@ def test_factory_missing_arg():
         return 7
 
     v = SchemaValidator(
-        {
-            'type': 'default',
-            'schema': {'type': 'int'},
-            'on_error': 'default',
-            'default_factory': broken,
-            'default_factory_takes_data': False,
-        }
+        core_schema.with_default_schema(
+            schema=core_schema.int_schema(),
+            on_error='default',
+            default_factory=broken,
+            default_factory_takes_data=False,
+        )
     )
     assert v.validate_python(42) == 42
     assert v.validate_python('42') == 42
@@ -247,16 +248,16 @@ def test_factory_missing_arg():
 
 def test_typed_dict_error():
     v = SchemaValidator(
-        {
-            'type': 'typed-dict',
-            'fields': {
-                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
-                'y': {
-                    'type': 'typed-dict-field',
-                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': lambda y: y * 2},
-                },
-            },
-        }
+        core_schema.typed_dict_schema(
+            fields={
+                'x': core_schema.typed_dict_field(schema=core_schema.str_schema()),
+                'y': core_schema.typed_dict_field(
+                    schema=core_schema.with_default_schema(
+                        schema=core_schema.str_schema(), default_factory=lambda y: y * 2
+                    )
+                ),
+            }
+        )
     )
     assert v.validate_python({'x': 'x', 'y': 'y'}) == {'x': 'x', 'y': 'y'}
     with pytest.raises(TypeError, match=r"<lambda>\(\) missing 1 required positional argument: 'y'"):
@@ -264,7 +265,9 @@ def test_typed_dict_error():
 
 
 def test_on_error_default_not_int():
-    v = SchemaValidator({'type': 'default', 'schema': {'type': 'int'}, 'default': [1, 2, 3], 'on_error': 'default'})
+    v = SchemaValidator(
+        core_schema.with_default_schema(schema=core_schema.int_schema(), default=[1, 2, 3], on_error='default')
+    )
     assert v.validate_python(42) == 42
     assert v.validate_python('42') == 42
     assert v.validate_python('wrong') == [1, 2, 3]
@@ -272,7 +275,7 @@ def test_on_error_default_not_int():
 
 def test_on_error_default_factory():
     v = SchemaValidator(
-        {'type': 'default', 'schema': {'type': 'int'}, 'default_factory': lambda: 17, 'on_error': 'default'}
+        core_schema.with_default_schema(schema=core_schema.int_schema(), default_factory=lambda: 17, on_error='default')
     )
     assert v.validate_python(42) == 42
     assert v.validate_python('42') == 42
@@ -280,7 +283,7 @@ def test_on_error_default_factory():
 
 
 def test_on_error_omit():
-    v = SchemaValidator({'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'})
+    v = SchemaValidator(core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='omit'))
     assert v.validate_python(42) == 42
     with pytest.raises(SchemaError, match='Uncaught Omit error, please check your usage of `default` validators.'):
         v.validate_python('wrong')
@@ -288,12 +291,16 @@ def test_on_error_omit():
 
 def test_on_error_wrong():
     with pytest.raises(SchemaError, match="'on_error = default' requires a `default` or `default_factory`"):
-        SchemaValidator({'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'default'})
+        SchemaValidator(core_schema.with_default_schema(schema=core_schema.int_schema(), on_error='default'))
 
 
 def test_build_default_and_default_factory():
     with pytest.raises(SchemaError, match="'default' and 'default_factory' cannot be used together"):
-        SchemaValidator({'type': 'default', 'schema': {'type': 'int'}, 'default_factory': lambda: 1, 'default': 2})
+        SchemaValidator(
+            schema=core_schema.with_default_schema(
+                schema=core_schema.int_schema(), default_factory=lambda: 1, default=2
+            )
+        )
 
 
 def test_model_class():
@@ -303,22 +310,19 @@ def test_model_class():
         field_b: int
 
     v = SchemaValidator(
-        {
-            'type': 'model',
-            'cls': MyModel,
-            'schema': {
-                'type': 'default',
-                'schema': {
-                    'type': 'model-fields',
-                    'fields': {
-                        'field_a': {'type': 'model-field', 'schema': {'type': 'str'}},
-                        'field_b': {'type': 'model-field', 'schema': {'type': 'int'}},
-                    },
-                },
-                'default': ({'field_a': '[default-a]', 'field_b': '[default-b]'}, None, set()),
-                'on_error': 'default',
-            },
-        }
+        core_schema.model_schema(
+            cls=MyModel,
+            schema=core_schema.with_default_schema(
+                schema=core_schema.model_fields_schema(
+                    fields={
+                        'field_a': core_schema.model_field(schema=core_schema.str_schema()),
+                        'field_b': core_schema.model_field(schema=core_schema.int_schema()),
+                    }
+                ),
+                default=({'field_a': '[default-a]', 'field_b': '[default-b]'}, None, set()),
+                on_error='default',
+            ),
+        )
     )
     m = v.validate_python({'field_a': 'test', 'field_b': 12})
     assert isinstance(m, MyModel)
@@ -440,35 +444,27 @@ def test_deepcopy_mutable_defaults():
         str_dict_with_default: dict[str, str] = stored_empty_dict
 
     v = SchemaValidator(
-        {
-            'type': 'model',
-            'cls': Model,
-            'schema': {
-                'type': 'model-fields',
-                'fields': {
-                    'int_list_with_default': {
-                        'type': 'model-field',
-                        'schema': {
-                            'type': 'default',
-                            'schema': {'type': 'list', 'items_schema': {'type': 'int'}},
-                            'default': stored_empty_list,
-                        },
-                    },
-                    'str_dict_with_default': {
-                        'type': 'model-field',
-                        'schema': {
-                            'type': 'default',
-                            'schema': {
-                                'type': 'dict',
-                                'keys_schema': {'type': 'str'},
-                                'values_schema': {'type': 'str'},
-                            },
-                            'default': stored_empty_dict,
-                        },
-                    },
-                },
-            },
-        }
+        core_schema.model_schema(
+            cls=Model,
+            schema=core_schema.model_fields_schema(
+                fields={
+                    'int_list_with_default': core_schema.model_field(
+                        schema=core_schema.with_default_schema(
+                            schema=core_schema.list_schema(items_schema=core_schema.int_schema()),
+                            default=stored_empty_list,
+                        )
+                    ),
+                    'str_dict_with_default': core_schema.model_field(
+                        schema=core_schema.with_default_schema(
+                            schema=core_schema.dict_schema(
+                                keys_schema=core_schema.str_schema(), values_schema=core_schema.str_schema()
+                            ),
+                            default=stored_empty_dict,
+                        )
+                    ),
+                }
+            ),
+        )
     )
 
     m1 = v.validate_python({})
@@ -504,7 +500,7 @@ def test_default_value() -> None:
 def test_default_value_validate_default() -> None:
     s = core_schema.with_default_schema(core_schema.list_schema(core_schema.int_schema()), default=['1', '2', '3'])
 
-    v = SchemaValidator(s, core_schema.CoreConfig(validate_default=True))
+    v = SchemaValidator(s, config=core_schema.CoreConfig(validate_default=True))
 
     r = v.get_default_value()
     assert r is not None
@@ -514,7 +510,7 @@ def test_default_value_validate_default() -> None:
 def test_default_value_validate_default_fail() -> None:
     s = core_schema.with_default_schema(core_schema.list_schema(core_schema.int_schema()), default=['a'])
 
-    v = SchemaValidator(s, core_schema.CoreConfig(validate_default=True))
+    v = SchemaValidator(s, config=core_schema.CoreConfig(validate_default=True))
 
     with pytest.raises(ValidationError) as exc_info:
         v.get_default_value()
@@ -531,7 +527,7 @@ def test_default_value_validate_default_fail() -> None:
 def test_default_value_validate_default_strict_pass() -> None:
     s = core_schema.with_default_schema(core_schema.list_schema(core_schema.int_schema()), default=[1, 2, 3])
 
-    v = SchemaValidator(s, core_schema.CoreConfig(validate_default=True))
+    v = SchemaValidator(s, config=core_schema.CoreConfig(validate_default=True))
 
     r = v.get_default_value(strict=True)
     assert r is not None
@@ -541,7 +537,7 @@ def test_default_value_validate_default_strict_pass() -> None:
 def test_default_value_validate_default_strict_fail() -> None:
     s = core_schema.with_default_schema(core_schema.list_schema(core_schema.int_schema()), default=['1'])
 
-    v = SchemaValidator(s, core_schema.CoreConfig(validate_default=True))
+    v = SchemaValidator(s, config=core_schema.CoreConfig(validate_default=True))
 
     with pytest.raises(ValidationError) as exc_info:
         v.get_default_value(strict=True)
@@ -553,7 +549,7 @@ def test_default_value_validate_default_strict_fail() -> None:
 @pytest.mark.parametrize('validate_default', [True, False])
 def test_no_default_value(validate_default: bool) -> None:
     s = core_schema.list_schema(core_schema.int_schema())
-    v = SchemaValidator(s, core_schema.CoreConfig(validate_default=validate_default))
+    v = SchemaValidator(s, config=core_schema.CoreConfig(validate_default=validate_default))
 
     assert v.get_default_value() is None
 
@@ -600,7 +596,11 @@ def f(v: Union[Some[Any], None]) -> str:
     res = f(SchemaValidator(core_schema.with_default_schema(core_schema.int_schema(), default=3)).get_default_value())
     assert res == 'case3: 3'
 
-    res = f(SchemaValidator(core_schema.with_default_schema(core_schema.int_schema(), default='4')).get_default_value())
+    res = f(
+        SchemaValidator(
+            schema=core_schema.with_default_schema(core_schema.int_schema(), default='4')
+        ).get_default_value()
+    )
     assert res == 'case4: str(4)'
 
     res = f(SchemaValidator(core_schema.int_schema()).get_default_value())
@@ -636,6 +636,7 @@ def test_use_default_error() -> None:
         validator.validate_python('')
 
 
+@pytest.mark.xfail(is_free_threaded, reason='GC leaks on free-threaded')
 @pytest.mark.xfail(
     condition=platform.python_implementation() == 'PyPy', reason='https://foss.heptapod.net/pypy/pypy/-/issues/3899'
 )
